* [Home](https://help.sap.com/docs/)


#  Link Disclaimer
Some links are classified by an icon and/or a mouseover text. These links provide additional information.
About the icons:
  * **Links with the icon**![Icon representing linked content on a non-SAP site](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fgraphql.org%2F) : You are entering a Web site that is not hosted by SAP. By using such links, you agree (unless expressly stated otherwise in your agreements with SAP) to this:
    * The content of the linked-to site is not SAP documentation. You may not infer any product claims against SAP based on this information.
    * SAP does not agree or disagree with the content on the linked-to site, nor does SAP warrant the availability and correctness. SAP shall not be liable for any damages caused by the use of such content unless damages have been caused by SAP's gross negligence or willful misconduct.
  * **Links with the icon**![Icon representing linked content on an SAP site](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fgraphql.org%2F) : You are leaving the documentation for that particular SAP product or service and are entering a SAP-hosted Web site. By using such links, you agree that (unless expressly stated otherwise in your agreements with SAP) you may not infer any product claims against SAP based on this information.
